==> haskell-hasql-notifications-0.2.0.5-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-CiE8vxqbRBh555Dz76xgCH
key:                  hasql-notifications-0.2.0.5-CiE8vxqbRBh555Dz76xgCH
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  fc0ead7b32f8f4c752964728b3b8196c
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-CiE8vxqbRBh555Dz76xgCH
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-2MA0O7B5YEkJtUYwQAtsrP
    hasql-pool-0.5.2.2-85pIxnc5GzKLduUcnNGRKK
    postgresql-libpq-0.9.5.0-ISIgXFjP19REFuF01eqmjw text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-notifications-0.2.0.5-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-ENSTKHeOeWp70mrtWAz4Ia
key:                  hasql-notifications-0.2.0.5-ENSTKHeOeWp70mrtWAz4Ia
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  8d2ece49cc98df3403ed139d29894753
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-ENSTKHeOeWp70mrtWAz4Ia
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-EqPauGcvJXT5PWBRze4diD
    hasql-pool-0.5.2.2-JJX6wU4dnR9CpGdH2fd1Nl
    postgresql-libpq-0.9.5.0-ISIgXFjP19REFuF01eqmjw text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
